searchData={"items":[{"type":"module","title":"Microformats2","doc":"A [microformats2](http://microformats.org/wiki/microformats2) parser for Elixir.","ref":"Microformats2.html"},{"type":"function","title":"Microformats2.parse/3","doc":"Parse a document either by URL or by content. Returns a microformats2 parsing structure or `:error`.","ref":"Microformats2.html#parse/3"},{"type":"function","title":"Parameters - Microformats2.parse/3","doc":"* `content_or_url` is either the HTML document or a URL\n  * `base_url_or_opts` is either the base URL of the document (if the first argument is a HTML string) or a\n    keyword list of options\n  * `opts` is an option list when the first argument is an HTML string","ref":"Microformats2.html#parse/3-parameters"},{"type":"function","title":"Options - Microformats2.parse/3","doc":"Valid options are:\n\n  * `:atomize_keys`: `true` or `false`, defaults to `false`. Convert keys to atoms when true, e.g. `\"rels\"` to `:rels`\n  * `:underscore_keys`: `true` or `false`, `false` by default. Convert dashed keys to underscored keys when true,\n    e.g. `\"rel-urls\"` to `\"rel_urls\"` or `:\"rel-urls\"` to `:rel_urls`","ref":"Microformats2.html#parse/3-options"},{"type":"function","title":"Examples - Microformats2.parse/3","doc":"iex> Microformats2.parse(\"http://example.org/\")\n    %{\"rels\" => [], \"rel-urls\" => [], \"items\" => []}\n\n    iex> Microformats2.parse(\"http://example.org/\", atomize_keys: true, underscore_keys: true)\n    %{rels: [], rel_urls: [], items: []}\n\n    iex> Microformats2.parse(\"\"\"\n     \n       \n       Mitchell Baker \n      ( @MitchellBaker )\n       Mozilla Foundation \n       \n        Mitchell is responsible for setting the direction and scope of the Mozilla Foundation and its activities.\n       \n       Strategy \n       Leadership \n     \n    \"\"\", \"http://example.org\")\n    %{\n      \"items\" => [\n        %{\n          \"properties\" => %{\n            \"category\" => [\"Strategy\", \"Leadership\"],\n            \"name\" => [\"Mitchell Baker\"],\n            \"note\" => [\"Mitchell is responsible for setting the direction and scope of the Mozilla Foundation and its activities.\"],\n            \"org\" => [\"Mozilla Foundation\"],\n            \"photo\" => [\n              %{\n                \"alt\" => \"photo of Mitchell\",\n                \"value\" => \"https://webfwd.org/content/about-experts/300.mitchellbaker/mentor_mbaker.jpg\"\n              }\n            ],\n            \"url\" => [\"http://blog.lizardwrangler.com/\",\n             \"https://twitter.com/MitchellBaker\"]\n          },\n          \"type\" => [\"h-card\"]\n        }\n      ],\n      \"rel-urls\" => %{},\n      \"rels\" => %{}\n    }","ref":"Microformats2.html#parse/3-examples"},{"type":"extras","title":"License","doc":"# The MIT License\n\nCopyright (c) 2018 Christian Kruse  \n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"},{"type":"extras","title":"Overview","doc":"# Microformats2\n\n[![Module Version](https://img.shields.io/hexpm/v/microformats2.svg)](https://hex.pm/packages/microformats2)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/microformats2/)\n[![Total Download](https://img.shields.io/hexpm/dt/microformats2.svg)](https://hex.pm/packages/microformats2)\n[![License](https://img.shields.io/hexpm/l/microformats2.svg)](https://github.com/ckruse/microformats2-elixir/blob/master/LICENSE.md)\n[![Last Updated](https://img.shields.io/github/last-commit/ckruse/microformats2-elixir.svg)](https://github.com/ckruse/microformats2-elixir/commits/master)\n\nA [Microformats2](http://microformats.org/wiki/microformats2) parser for Elixir.","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"The package can be installed by adding `:microformat2` to your list of\ndependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:microformats2, \"~> 1.0.0\"}\n  ]\nend\n```\n\nIf you want to directly `parse` from URLs, add `:tesla` to your list of\ndependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:microformats2, \"~> 1.0.0\"},\n    {:tesla, \"~> 1.4.4\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Overview","doc":"Give the parser an HTML string and the URL it was fetched from:\n\n```elixir\nMicroformats2.parse(\"\"\"\n \n   \n   Mitchell Baker \n  ( @MitchellBaker )\n   Mozilla Foundation \n   \n    Mitchell is responsible for setting the direction and scope of the Mozilla Foundation and its activities.\n   \n   Strategy \n   Leadership \n \n\"\"\", \"http://example.org\")\n```\n\nIt will parse the object to a structure like that:\n\n```elixir\n%{\n  \"items\" => [\n    %{\n      \"properties\" => %{\n        \"category\" => [\"Strategy\", \"Leadership\"],\n        \"name\" => [\"Mitchell Baker\"],\n        \"note\" => [\"Mitchell is responsible for setting the direction and scope of the Mozilla Foundation and its activities.\"],\n        \"org\" => [\"Mozilla Foundation\"],\n        \"photo\" => [\n          %{\n            \"alt\" => \"photo of Mitchell\",\n            \"value\" => \"https://webfwd.org/content/about-experts/300.mitchellbaker/mentor_mbaker.jpg\"\n          }\n        ],\n        \"url\" => [\"http://blog.lizardwrangler.com/\",\n         \"https://twitter.com/MitchellBaker\"]\n      },\n      \"type\" => [\"h-card\"]\n    }\n  ],\n  \"rel-urls\" => %{},\n  \"rels\" => %{}\n}\n```\n\nYou can also provide HTML trees already parsed with Floki:\n\n```elixir\nMicroformats2.parse(Floki.parse(\" ... \"), \"http://example.org\")\n```\n\nOr URLs if you have Tesla installed:\n\n```elixir\nMicroformats2.parse(\"http://example.org\")\n```","ref":"readme.html#usage"},{"type":"extras","title":"Dependencies - Overview","doc":"We need [Floki](https://github.com/philss/floki) for HTML parsing and optionally\n[Tesla](https://github.com/teamon/tesla) for fetching URLs.","ref":"readme.html#dependencies"},{"type":"extras","title":"Features - Overview","doc":"Implemented:\n\n- [parsing depth first, doc order](http://microformats.org/wiki/microformats2-parsing#parse_a_document_for_microformats)\n- [parsing a p- property](http://microformats.org/wiki/microformats2-parsing#parsing_a_p-_property)\n- [parsing a u- property](http://microformats.org/wiki/microformats2-parsing#parsing_a_u-_property)\n- [parsing a dt- property](http://microformats.org/wiki/microformats2-parsing#parsing_a_dt-_property)\n- [parsing a e- property](http://microformats.org/wiki/microformats2-parsing#parsing_an_e-_property)\n- [parsing implied properties](http://microformats.org/wiki/microformats-2-parsing#parsing_for_implied_properties)\n- nested properties\n- nested microformat with associated property\n- dynamic creation of properties\n- [rel](http://microformats.org/wiki/rel)\n- nested microformat without associated property\n- [normalize u-\\* property values](http://microformats.org/wiki/microformats2-parsing-faq#normalizing_u-.2A_property_values)\n- [value-class-pattern](http://microformats.org/wiki/value-class-pattern)\n- recognition of [vendor extensions](http://microformats.org/wiki/microformats2#VENDOR_EXTENSIONS)\n\nNot implemented:\n\n- [include-pattern](http://microformats.org/wiki/include-pattern)\n- backwards compatible support for microformats v1","ref":"readme.html#features"},{"type":"extras","title":"Copyright and License - Overview","doc":"Copyright (c) 2018 Christian Kruse  \n\nThis work is free. You can redistribute it and/or modify it under the\nterms of the MIT License. See the [LICENSE.md](./LICENSE.md) file for more details.","ref":"readme.html#copyright-and-license"}],"content_type":"text/markdown"}